@@ -27,27 +27,27 @@ def base_logger(log_name: str = 'default', file_path: str = './', mode: str = 'D
     logger = logging.getLogger(log_name)
     logger.setLevel(log_level[mode])
     formatter = logging.Formatter('%(asctime)s @zkr@ %(pathname)s @zkr@ %(lineno)d @zkr@ %(name)s @zkr@ %(levelname)s @zkr@ %(message)s')
+    #  这里进行判断，如果logger.handlers列表为空，则添加，否则，直接去写日志
+    if not logger.handlers:
+        handlers = set()
+        if not os.path.exists(file_path):
+            os.makedirs(file_path)
+        log_name = os.path.join(file_path, log_name)
+        fh = RotatingFileHandler(filename='{name}.log'.format(name=log_name),
+                                 maxBytes=1024*1024*50, backupCount=5,
+                                 encoding="utf-8",delay=False)
 
-    handlers = set()
+        fh.setFormatter(formatter)
+        handlers.add(fh)
+        #  这里进行判断，如果logger.handlers列表为空，则添加，否则，直接去写日志
+        if mode == 'DEBUG' or cmd_output:
+            ch = logging.StreamHandler()
+            ch.setLevel(log_level[mode])
+            ch.setFormatter(formatter)
+            handlers.add(ch)
 
-    if not os.path.exists(file_path):
-        os.makedirs(file_path)
-    log_name = os.path.join(file_path, log_name)
-    fh = RotatingFileHandler(filename='{name}.log'.format(name=log_name),
-                             maxBytes=1024*1024*50, backupCount=5,
-                             encoding="utf-8",delay=False)
-
-    fh.setFormatter(formatter)
-    handlers.add(fh)
-
-    if mode == 'DEBUG' or cmd_output:
-        ch = logging.StreamHandler()
-        ch.setLevel(log_level[mode])
-        ch.setFormatter(formatter)
-        handlers.add(ch)
-
-    for handler in handlers:
-        logger.addHandler(handler)
+        for handler in handlers:
+            logger.addHandler(handler)
 
     return logger
 
